agentle.agents.whatsapp.providers.evolution
===========================================

.. automodule:: agentle.agents.whatsapp.providers.evolution

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   evolution_api_config
   evolution_api_provider
